@@ -3,6 +3,7 @@ A logger that gets dumped to stdout when closed
 """
 
 import inspect
+import itertools
 import logging
 import os
 from logging.handlers import MemoryHandler
@@ -14,6 +15,8 @@ class MemoryLogger:
     A logger that gets dumped to stdout when closed
     """
 
+    id_iter = itertools.count()
+
     def __init__(
         self,
         file_name: str,
@@ -21,12 +24,13 @@ class MemoryLogger:
         log_name: Optional[str] = None,
         flush_immed: bool = False,
     ) -> None:
+        self.instance_id = next(self.id_iter)
         self.flush_immed = flush_immed
         self.lock = lock
 
         if log_name is None:
             caller = inspect.stack()[1][0].f_locals["self"].__class__.__name__
-            log_name = f"{caller}--{os.getpid()}"
+            log_name = f"{caller}--{os.getpid()}-{self.instance_id}"
 
         self._logger = logging.getLogger(log_name)
 
